@@ -654,104 +654,6 @@ gpk_strv_join_locale (gchar **array)
 	return NULL;
 }
 
-/**
- * gpk_package_entry_completion_get_names_from_file:
- *
- * Creates a tree model containing completions from the system package list
- **/
-static GPtrArray *
-gpk_package_entry_completion_get_names_from_file (const gchar *filename)
-{
-	GPtrArray *array = NULL;
-	gboolean ret;
-	GError *error = NULL;
-	gchar *data = NULL;
-	gchar **lines = NULL;
-	guint i;
-	gchar **split;
-	PkPackage *item;
-
-	/* get data */
-	ret = g_file_get_contents (filename, &data, NULL, &error);
-	if (!ret) {
-		g_warning ("failed to open package list: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* create array of PkPackage's */
-	array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
-
-	/* split */
-	lines = g_strsplit (data, "\n", -1);
-	for (i=0; lines[i] != NULL; i++) {
-		split = g_strsplit (lines[i], "\t", 3);
-		if (g_strv_length (split) != 3)
-			continue;
-		item = pk_package_new ();
-		pk_package_set_id (item, split[1], NULL);
-		g_object_set (item,
-			      "info", pk_info_enum_from_string (split[0]),
-			      "summary", split[2],
-			      NULL);
-		g_ptr_array_add (array, item);
-		g_strfreev (split);
-	}
-out:
-	g_free (data);
-	g_strfreev (lines);
-	return array;
-}
-
-/**
- * gpk_package_entry_completion_model_new:
- *
- * Creates a tree model containing completions from the system package list
- **/
-static GtkTreeModel *
-gpk_package_entry_completion_model_new (void)
-{
-	GPtrArray *list;
-	guint i;
-	PkPackage *item;
-	GHashTable *hash;
-	gpointer data;
-	GtkListStore *store;
-	GtkTreeIter iter;
-	gchar **split;
-
-	store = gtk_list_store_new (1, G_TYPE_STRING);
-	hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
-	list = gpk_package_entry_completion_get_names_from_file (PK_SYSTEM_PACKAGE_LIST_FILENAME);
-	if (list == NULL) {
-		g_warning ("no package list, try refreshing");
-		return NULL;
-	}
-
-	g_debug ("loading %i autocomplete items", list->len);
-	for (i=0; i<list->len; i++) {
-		item = g_ptr_array_index (list, i);
-		if (item == NULL || pk_package_get_id (item) == NULL) {
-			g_warning ("item invalid!");
-			break;
-		}
-
-		split = pk_package_id_split (pk_package_get_id (item));
-		data = g_hash_table_lookup (hash, (gpointer) split[PK_PACKAGE_ID_NAME]);
-		if (data == NULL) {
-			/* append just the name */
-			g_hash_table_insert (hash, g_strdup (split[PK_PACKAGE_ID_NAME]), GINT_TO_POINTER (1));
-			gtk_list_store_append (store, &iter);
-			gtk_list_store_set (store, &iter, 0, split[PK_PACKAGE_ID_NAME], -1);
-		}
-		g_strfreev (split);
-	}
-	g_hash_table_unref (hash);
-	g_ptr_array_unref (list);
-
-	return GTK_TREE_MODEL (store);
-}
-
 /**
  * gpk_package_entry_completion_new:
  *
@@ -760,22 +662,5 @@ gpk_package_entry_completion_model_new (void)
 GtkEntryCompletion *
 gpk_package_entry_completion_new (void)
 {
-	GtkEntryCompletion *completion;
-	GtkTreeModel *model;
-
-	/* create a tree model and use it as the completion model */
-	completion = gtk_entry_completion_new ();
-	model = gpk_package_entry_completion_model_new ();
-	if (model == NULL)
-		return completion;
-
-	/* set the model for our completion model */
-	gtk_entry_completion_set_model (completion, model);
-	g_object_unref (model);
-
-	/* use model column 0 as the text column */
-	gtk_entry_completion_set_text_column (completion, 0);
-	gtk_entry_completion_set_inline_completion (completion, TRUE);
-
-	return completion;
+	return NULL;
 }
