@@ -31,7 +31,6 @@
 #include "gpk-common.h"
 #include "gpk-dialog.h"
 #include "gpk-enum.h"
-#include "gpk-desktop.h"
 
 enum {
 	GPK_DIALOG_STORE_IMAGE,
@@ -84,7 +83,6 @@ gpk_dialog_package_array_to_list_store (GPtrArray *array)
 	GtkListStore *store;
 	GtkTreeIter iter;
 	PkPackage *item;
-	PkDesktop *desktop;
 	const gchar *icon;
 	gchar *text;
 	guint i;
@@ -93,7 +91,6 @@ gpk_dialog_package_array_to_list_store (GPtrArray *array)
 	gchar *package_id = NULL;
 	gchar *summary = NULL;
 
-	desktop = pk_desktop_new ();
 	store = gtk_list_store_new (GPK_DIALOG_STORE_LAST, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
 	/* add each well */
@@ -108,9 +105,7 @@ gpk_dialog_package_array_to_list_store (GPtrArray *array)
 
 		/* get the icon */
 		split = pk_package_id_split (package_id);
-		icon = gpk_desktop_guess_icon_name (desktop, split[0]);
-		if (icon == NULL)
-			icon = gpk_info_enum_to_icon_name (info);
+		icon = gpk_info_enum_to_icon_name (info);
 
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
@@ -124,7 +119,6 @@ gpk_dialog_package_array_to_list_store (GPtrArray *array)
 		g_free (text);
 	}
 
-	g_object_unref (desktop);
 	return store;
 }
 
@@ -319,50 +313,6 @@ gpk_dialog_embed_do_not_show_widget (GtkDialog *dialog, const gchar *key)
 	return TRUE;
 }
 
-/**
- * gpk_dialog_embed_download_size_widget:
- **/
-gboolean
-gpk_dialog_embed_download_size_widget (GtkDialog *dialog, const gchar *title, guint64 size)
-{
-	GtkWidget *label;
-	GtkWidget *hbox;
-	GtkWidget *widget;
-	gchar *text = NULL;
-	gchar *size_str = NULL;
-
-	/* size is zero, don't show "0 bytes" */
-	if (size == 0) {
-		label = gtk_label_new (title);
-		widget = gtk_dialog_get_content_area (GTK_DIALOG(dialog));
-		gtk_container_add_with_properties (GTK_CONTAINER (widget), label,
-						   "expand", FALSE,
-						   "fill", FALSE,
-						   NULL);
-		goto out;
-	}
-
-	/* add a hbox with the size for deps screen */
-	size_str = g_format_size (size);
-	text = g_strdup_printf ("%s: %s", title, size_str);
-	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-	widget = gtk_dialog_get_content_area (GTK_DIALOG(dialog));
-	gtk_container_add_with_properties (GTK_CONTAINER (widget), hbox,
-					   "expand", FALSE,
-					   "fill", FALSE,
-					   NULL);
-
-	/* add a label */
-	label = gtk_label_new (text);
-	gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (hbox);
-out:
-	gtk_widget_show (label);
-	g_free (text);
-	g_free (size_str);
-	return TRUE;
-}
-
 /**
  * gpk_dialog_embed_tabbed_widget
  **/
