@@ -148,8 +148,10 @@ static const PkEnumMatch enum_role_icon_name[] = {
 	{PK_ROLE_ENUM_DOWNLOAD_PACKAGES,	"pk-package-download"},
 	{PK_ROLE_ENUM_GET_CATEGORIES,		"pk-package-info"},
 	{PK_ROLE_ENUM_GET_DETAILS,		"pk-package-info"},
+	{PK_ROLE_ENUM_GET_DETAILS_LOCAL,	"pk-package-search"},
 	{PK_ROLE_ENUM_GET_DISTRO_UPGRADES,	"pk-package-info"},
 	{PK_ROLE_ENUM_GET_FILES,		"pk-package-search"},
+	{PK_ROLE_ENUM_GET_FILES_LOCAL,		"pk-package-search"},
 	{PK_ROLE_ENUM_GET_OLD_TRANSACTIONS,	"pk-package-info"},
 	{PK_ROLE_ENUM_GET_PACKAGES,		"pk-package-search"},
 	{PK_ROLE_ENUM_GET_REPO_LIST,		"pk-package-sources"},
@@ -162,6 +164,7 @@ static const PkEnumMatch enum_role_icon_name[] = {
 	{PK_ROLE_ENUM_REMOVE_PACKAGES,		"pk-package-delete"},
 	{PK_ROLE_ENUM_REPO_ENABLE,		"pk-package-sources"},
 	{PK_ROLE_ENUM_REPO_SET_DATA,		"pk-package-sources"},
+	{PK_ROLE_ENUM_REPO_REMOVE,		"pk-package-sources"},
 	{PK_ROLE_ENUM_REQUIRED_BY,		"pk-package-info"},
 	{PK_ROLE_ENUM_RESOLVE,			"pk-package-search"},
 	{PK_ROLE_ENUM_SEARCH_DETAILS,		"pk-package-search"},
@@ -358,7 +361,7 @@ gpk_error_enum_to_localised_text (PkErrorEnum code)
 		text = _("Packages are not compatible");
 		break;
 	case PK_ERROR_ENUM_REPO_NOT_AVAILABLE:
-		text = _("Problem connecting to a software source");
+		text = _("Problem connecting to a package source");
 		break;
 	case PK_ERROR_ENUM_FAILED_INITIALIZATION:
 		text = _("Failed to initialize");
@@ -518,14 +521,14 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 			 "Please report this bug in your distribution bug tracker with the error description.");
 		break;
 	case PK_ERROR_ENUM_GPG_FAILURE:
-		text = _("A security trust relationship could not be made with software source.\n"
+		text = _("A security trust relationship could not be made with package source.\n"
 			 "Please check your security settings.");
 		break;
 	case PK_ERROR_ENUM_PACKAGE_NOT_INSTALLED:
 		text = _("The package that is trying to be removed or updated is not already installed.");
 		break;
 	case PK_ERROR_ENUM_PACKAGE_NOT_FOUND:
-		text = _("The package that is being modified was not found on your system or in any software source.");
+		text = _("The package that is being modified was not found on your system or in any package source.");
 		break;
 	case PK_ERROR_ENUM_PACKAGE_ALREADY_INSTALLED:
 		text = _("The package that is trying to be installed is already installed.");
@@ -559,8 +562,8 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 			 "More information is available in the detailed report.");
 		break;
 	case PK_ERROR_ENUM_REPO_NOT_FOUND:
-		text = _("The remote software source name was not found.\n"
-			 "You may need to enable an item in Software Sources.");
+		text = _("The remote package source name was not found.\n"
+			 "You may need to enable an item in Package Sources.");
 		break;
 	case PK_ERROR_ENUM_CANNOT_REMOVE_SYSTEM_PACKAGE:
 		text = _("Removing a protected system package is not allowed.");
@@ -589,14 +592,14 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 		break;
 	case PK_ERROR_ENUM_FILE_CONFLICTS:
 		text = _("Two packages provide the same file.\n"
-			 "This is usually due to mixing packages from different software sources.");
+			 "This is usually due to mixing packages from different sources.");
 		break;
 	case PK_ERROR_ENUM_PACKAGE_CONFLICTS:
 		text = _("Multiple packages exist that are not compatible with each other.\n"
-			 "This is usually due to mixing packages from different software sources.");
+			 "This is usually due to mixing packages from different sources.");
 		break;
 	case PK_ERROR_ENUM_REPO_NOT_AVAILABLE:
-		text = _("There was a (possibly temporary) problem connecting to a software source.\n"
+		text = _("There was a (possibly temporary) problem connecting to a package source.\n"
 			 "Please check the detailed error for further details.");
 		break;
 	case PK_ERROR_ENUM_FAILED_INITIALIZATION:
@@ -649,11 +652,11 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 			 "Check the file still exists and has not been deleted.");
 		break;
 	case PK_ERROR_ENUM_NO_MORE_MIRRORS_TO_TRY:
-		text = _("Required data could not be found on any of the configured software sources.\n"
+		text = _("Required data could not be found on any of the configured package sources.\n"
 			 "There were no more download mirrors that could be tried.");
 		break;
 	case PK_ERROR_ENUM_NO_DISTRO_UPGRADE_DATA:
-		text = _("Required upgrade data could not be found in any of the configured software sources.\n"
+		text = _("Required upgrade data could not be found in any of the configured package sources.\n"
 			 "The list of distribution upgrades will be unavailable.");
 		break;
 	case PK_ERROR_ENUM_INCOMPATIBLE_ARCHITECTURE:
@@ -687,7 +690,7 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 		text = _("The information about what requires this package could not be obtained.");
 		break;
 	case PK_ERROR_ENUM_CANNOT_DISABLE_REPOSITORY:
-		text = _("The specified software source could not be disabled.");
+		text = _("The specified package source could not be disabled.");
 		break;
 	case PK_ERROR_ENUM_RESTRICTED_DOWNLOAD:
 		text = _("The download could not be done automatically and should be done manually.\n"
@@ -723,7 +726,7 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 		text = _("The install root is invalid. Please contact your administrator.");
 		break;
 	case PK_ERROR_ENUM_CANNOT_FETCH_SOURCES:
-		text = _("The list of software sources could not be downloaded.");
+		text = _("The list of package sources could not be downloaded.");
 		break;
 	case PK_ERROR_ENUM_UNFINISHED_TRANSACTION:
 		text = _("A previous package management transaction was interrupted.");
@@ -1211,6 +1214,7 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 		text = _("Getting update detail");
 		break;
 	case PK_ROLE_ENUM_GET_DETAILS:
+	case PK_ROLE_ENUM_GET_DETAILS_LOCAL:
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Getting details");
 		break;
@@ -1270,6 +1274,10 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Enabling repository");
 		break;
+	case PK_ROLE_ENUM_REPO_REMOVE:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = _("Removing repository");
+		break;
 	case PK_ROLE_ENUM_REPO_SET_DATA:
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Setting repository data");
@@ -1279,6 +1287,7 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 		text = _("Resolving");
 		break;
 	case PK_ROLE_ENUM_GET_FILES:
+	case PK_ROLE_ENUM_GET_FILES_LOCAL:
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Getting file list");
 		break;
@@ -1347,6 +1356,7 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		text = _("Got update detail");
 		break;
 	case PK_ROLE_ENUM_GET_DETAILS:
+	case PK_ROLE_ENUM_GET_DETAILS_LOCAL:
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Got details");
 		break;
@@ -1406,6 +1416,10 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Enabled repository");
 		break;
+	case PK_ROLE_ENUM_REPO_REMOVE:
+		/* TRANSLATORS: The role of the transaction, in past tense */
+		text = _("Removed repository");
+		break;
 	case PK_ROLE_ENUM_REPO_SET_DATA:
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Set repository data");
@@ -1415,6 +1429,7 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		text = _("Resolved");
 		break;
 	case PK_ROLE_ENUM_GET_FILES:
+	case PK_ROLE_ENUM_GET_FILES_LOCAL:
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Got file list");
 		break;
@@ -1578,7 +1593,7 @@ gpk_group_enum_to_localised_text (PkGroupEnum group)
 		break;
 	case PK_GROUP_ENUM_REPOS:
 		/* TRANSLATORS: The group type */
-		text = _("Software sources");
+		text = _("Package sources");
 		break;
 	case PK_GROUP_ENUM_SCIENCE:
 		/* TRANSLATORS: The group type */
