@@ -47,36 +47,3 @@ gpk_gnome_open (const gchar *url)
 	}
 	return ret;
 }
-
-/**
- * gpk_gnome_help:
- * @link_id: Subsection of gnome-packagekit help file, or %NULL.
- **/
-gboolean
-gpk_gnome_help (const gchar *link_id)
-{
-	GError *error = NULL;
-	gchar *uri;
-	gboolean ret = TRUE;
-
-	if (link_id)
-		uri = g_strconcat ("help:gnome-packagekit/", link_id, NULL);
-	else
-		uri = g_strdup ("help:gnome-packagekit");
-	g_debug ("opening uri %s", uri);
-
-	gtk_show_uri (NULL, uri, GDK_CURRENT_TIME, &error);
-
-	if (error != NULL) {
-		GtkWidget *d;
-		d = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					    GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", error->message);
-		gtk_dialog_run (GTK_DIALOG(d));
-		gtk_widget_destroy (d);
-		g_error_free (error);
-		ret = FALSE;
-	}
-
-	g_free (uri);
-	return ret;
-}
