@@ -30,7 +30,6 @@
 #include "gpk-gnome.h"
 #include "gpk-common.h"
 #include "gpk-enum.h"
-#include "gpk-desktop.h"
 
 static void     gpk_helper_chooser_finalize	(GObject	  *object);
 
@@ -39,7 +38,6 @@ static void     gpk_helper_chooser_finalize	(GObject	  *object);
 struct GpkHelperChooserPrivate
 {
 	GtkBuilder		*builder;
-	PkDesktop		*desktop;
 	gchar			*package_id;
 	GtkListStore		*list_store;
 };
@@ -155,7 +153,6 @@ gpk_helper_chooser_show (GpkHelperChooser *helper, GPtrArray *list)
 	guint i;
 	PkPackage *item;
 	GtkTreeIter iter;
-	gchar **split;
 	PkInfoEnum info;
 	gchar *package_id = NULL;
 	gchar *summary = NULL;
@@ -179,14 +176,7 @@ gpk_helper_chooser_show (GpkHelperChooser *helper, GPtrArray *list)
 		text = gpk_package_id_format_twoline (gtk_widget_get_style_context (widget),
 						      package_id,
 						      summary);
-
-		/* get the icon */
-		split = pk_package_id_split (package_id);
-		icon_name = gpk_desktop_guess_icon_name (helper->priv->desktop, split[PK_PACKAGE_ID_NAME]);
-		g_strfreev (split);
-		if (icon_name == NULL)
-			icon_name = gpk_info_enum_to_icon_name (info);
-
+		icon_name = gpk_info_enum_to_icon_name (info);
 		gtk_list_store_set (helper->priv->list_store, &iter,
 				    GPK_CHOOSER_COLUMN_TEXT, text,
 				    GPK_CHOOSER_COLUMN_ID, package_id, -1);
@@ -320,9 +310,6 @@ gpk_helper_chooser_init (GpkHelperChooser *helper)
 	pk_treeview_add_general_columns (GTK_TREE_VIEW (widget));
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (widget));
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (widget), FALSE);
-
-	/* use PkDesktop to get better icon */
-	helper->priv->desktop = pk_desktop_new ();
 }
 
 /**
@@ -344,7 +331,6 @@ gpk_helper_chooser_finalize (GObject *object)
 		gtk_widget_hide (widget);
 	g_free (helper->priv->package_id);
 	g_object_unref (helper->priv->builder);
-	g_object_unref (helper->priv->desktop);
 
 	G_OBJECT_CLASS (gpk_helper_chooser_parent_class)->finalize (object);
 }
